@@ -138,14 +138,20 @@ def portStr(port, delimiter=":"):
         return "%s%s%s" % (_range[0], delimiter, _range[1])
 
 def portInPortRange(port, range):
-    _port = getPortID(port)
+    _port = getPortRange(port)
     _range = getPortRange(range)
 
-    if len(_range) == 1:
-        return _port == getPortID(_range[0])
-    if len(_range) == 2 and \
-       _port >= getPortID(_range[0]) and _port <= getPortID(_range[1]):
-        return True
+    if len(_port) == 1:
+        if len(_range) == 1:
+            return getPortID(_port[0]) == getPortID(_range[0])
+        if len(_range) == 2 and \
+           getPortID(_port[0]) >= getPortID(_range[0]) and getPortID(_port[0]) <= getPortID(_range[1]):
+            return True
+    elif len(_port) == 2:
+        if len(_range) == 2 and \
+           getPortID(_port[0]) >= getPortID(_range[0]) and getPortID(_port[0]) <= getPortID(_range[1]) and \
+           getPortID(_port[1]) >= getPortID(_range[0]) and getPortID(_port[1]) <= getPortID(_range[1]):
+            return True
 
     return False
 
@@ -176,6 +182,14 @@ def checkIP(ip):
         return False
     return True
 
+def normalizeIP6(ip):
+    """ Normalize the IPv6 address
+
+    This is mostly about converting URL-like IPv6 address to normal ones.
+    e.g. [1234::4321] --> 1234:4321
+    """
+    return ip.strip("[]")
+
 def checkIP6(ip):
     """ Check IPv6 address.
     
@@ -184,7 +198,7 @@ def checkIP6(ip):
     """
 
     try:
-        socket.inet_pton(socket.AF_INET6, ip)
+        socket.inet_pton(socket.AF_INET6, normalizeIP6(ip))
     except socket.error:
         return False
     return True
